@@ -21,7 +21,8 @@ class Plugin(Plugin):
     # ui_label = _("React")
     ui_handle_attr_name = 'react_handle'
 
-    needs_plugins = ['lino.modlib.jinja', 'lino.modlib.memo']
+    # needs_plugins = ['lino.modlib.jinja', 'lino.modlib.memo']
+    needs_plugins = ['lino.modlib.system', 'lino.modlib.jinja']
     # disables_plugins = ['tinymce', 'extensible']
 
     url_prefix = 'react'
@@ -107,5 +108,5 @@ class Plugin(Plugin):
         if html is not None:
             yield ("React", '16.6', "https://reactjs.org/")
 
-    def get_requirements(self, site):
-        yield 'lino_react'
+    # def get_requirements(self, site):
+    #     yield 'lino_react'
