@@ -454,6 +454,14 @@ class Renderer(JsRenderer, JsCacheRenderer):
             status[constants.URL_PARAM_SUBST_USER] = ar.subst_user
         if isinstance(a, ShowEmptyTable):
             status.update(record_id=-99998)
+        if ar and ar.master_instance is not None:
+            mi = ar.master_instance
+            bp = {
+                constants.URL_PARAM_MASTER_PK: mi.pk}
+            if issubclass(mi.__class__, models.Model):
+                mt = ContentType.objects.get_for_model(mi.__class__)
+                bp[constants.URL_PARAM_MASTER_TYPE] = mt
+            status.update(base_params=bp)
         if an == 'grid' and hasattr(status, 'record_id'):
             del status['record_id']
 
